summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/mainboard/google/brya/variants/kuldax/ramstage.c38
1 files changed, 19 insertions, 19 deletions
diff --git a/src/mainboard/google/brya/variants/kuldax/ramstage.c b/src/mainboard/google/brya/variants/kuldax/ramstage.c
index 4bec1d4447..5a7123789a 100644
--- a/src/mainboard/google/brya/variants/kuldax/ramstage.c
+++ b/src/mainboard/google/brya/variants/kuldax/ramstage.c
@@ -20,45 +20,45 @@ const struct cpu_power_limits limits[] = {
const struct system_power_limits sys_limits[] = {
/* SKU_ID, TDP (Watts), psys_pl2 (Watts) */
- { PCI_DID_INTEL_ADL_P_ID_10, 15, 65 },
- { PCI_DID_INTEL_ADL_P_ID_7, 15, 150 },
- { PCI_DID_INTEL_ADL_P_ID_6, 15, 150 },
- { PCI_DID_INTEL_ADL_P_ID_5, 28, 150 },
- { PCI_DID_INTEL_ADL_P_ID_3, 28, 150 },
+ { PCI_DID_INTEL_ADL_P_ID_10, 15, 83 },
+ { PCI_DID_INTEL_ADL_P_ID_7, 15, 225 },
+ { PCI_DID_INTEL_ADL_P_ID_6, 15, 225 },
+ { PCI_DID_INTEL_ADL_P_ID_5, 28, 225 },
+ { PCI_DID_INTEL_ADL_P_ID_3, 28, 225 },
};
const struct system_power_limits revise_sys_limits[] = {
/* SKU_ID, TDP (Watts), psys_pl2 (Watts) */
- { PCI_DID_INTEL_ADL_P_ID_10, 15, 150 },
- { PCI_DID_INTEL_ADL_P_ID_7, 15, 150 },
- { PCI_DID_INTEL_ADL_P_ID_6, 15, 150 },
- { PCI_DID_INTEL_ADL_P_ID_5, 28, 150 },
- { PCI_DID_INTEL_ADL_P_ID_3, 28, 150 },
+ { PCI_DID_INTEL_ADL_P_ID_10, 15, 225 },
+ { PCI_DID_INTEL_ADL_P_ID_7, 15, 225 },
+ { PCI_DID_INTEL_ADL_P_ID_6, 15, 225 },
+ { PCI_DID_INTEL_ADL_P_ID_5, 28, 225 },
+ { PCI_DID_INTEL_ADL_P_ID_3, 28, 225 },
};
/*
* Psys_pmax considerations.
*
* Given the hardware design in kuldax, the serial shunt resistor is 0.005ohm.
- * The full scale of hardware PSYS signal 1.6v maps to system current 7.5A
+ * The full scale of hardware PSYS signal 1.6v maps to system current 11.25A
* instead of real system power. The equation is shown below:
- * PSYS = 1.6v = (0.01ohm x 7.5A) x 50 (INA213, gain 50V/V) x R501/(R501 + R510)
- * R501/(R501 + R510) = 0.858 = 20K / (20K + 3.3K)
+ * PSYS = 1.6v = (0.005ohm x 11.25A) x 50 (INA213, gain 50V/V) x R501/(R501 + R510)
+ * R501/(R501 + R510) = 0.57 = 20K / (20K + 15K)
*
* The Psys_pmax is a SW setting which tells IMVP9.1 the mapping b/w system input
* current and the actual system power. Since there is no voltage information
* from PSYS, different voltage input would map to different Psys_pmax settings:
* For Type-C 15V, the Psys_pmax should be 15v x 7.5A = 112.5W
* For Type-C 20V, the Psys_pmax should be 20v x 7.5A = 150W
* For a barrel jack, the Psys_pmax should be 20v x 7.5A = 150W
*
* Imagine that there is a type-c 100W (20V/5A) connected to DUT w/ full loading,
* and the Psys_pmax setting is 150W. Then IMVP9.1 can calculate the current system
* power = 150W * 5A / 7.5A = 100W, which is the actual system power.
*/
const struct psys_config psys_config = {
.efficiency = 97,
- .psys_imax_ma = 7500,
+ .psys_imax_ma = 11250,
.bj_volts_mv = 20000
};
@@ -20,45 +20,45 @@ const struct cpu_power_limits limits[] = {
* current and the actual system power. Since there is no voltage information
* from PSYS, different voltage input would map to different Psys_pmax settings:
- * For Type-C 15V, the Psys_pmax should be 15v x 7.5A = 112.5W
- * For Type-C 20V, the Psys_pmax should be 20v x 7.5A = 150W
- * For a barrel jack, the Psys_pmax should be 20v x 7.5A = 150W
+ * For Type-C 15V, the Psys_pmax should be 15v x 11.25A = 168.75W
+ * For Type-C 20V, the Psys_pmax should be 20v x 11.25A = 225W
+ * For a barrel jack, the Psys_pmax should be 20v x 11.25A = 225W
*
* Imagine that there is a type-c 100W (20V/5A) connected to DUT w/ full loading,
@@ -20,45 +20,45 @@ const struct cpu_power_limits limits[] = {
*
* Imagine that there is a type-c 100W (20V/5A) connected to DUT w/ full loading,
- * and the Psys_pmax setting is 150W. Then IMVP9.1 can calculate the current system
- * power = 150W * 5A / 7.5A = 100W, which is the actual system power.
+ * and the Psys_pmax setting is 225W. Then IMVP9.1 can calculate the current system
+ * power = 225W * 5A / 11.25A = 100W, which is the actual system power.
*/
const struct psys_config psys_config = {